@@ -6,9 +6,9 @@ class ResultNameMappingError(JournalError):
     """Error mapping results."""
 
 
-class FormatterError(JournalError):
-    """Unable to format log message."""
-
-
-class EncoderError(JournalError):
-    """Error dictionary encoding object."""
+# class FormatterError(JournalError):
+#     """Unable to format log message."""
+#
+#
+# class EncoderError(JournalError):
+#     """Error dictionary encoding object."""
